# Add a new dataset

1. Add metadatas in `src/corpora/corpora.json`  

    Example:
        
        {
            "name": "TIMIT",
            "lang": "eng",
            "license": "LDC User Agreement for Non-Members",
            "source": "https://catalog.ldc.upenn.edu/LDC93S1",
            "authors": ["John S. Garofolo", "Lori F. Lamel", "William M. Fisher", "Jonathan G. Fiscus", "David S. Pallett", "Nancy L. Dahlgren", "Victor Zue"],
            "description": "The TIMIT corpus of read speech has been designed to provide speech data for the acquisition of acoustic-phonetic knowledge and for the development and evaluation of automatic speech recognition systems.",
            "subsets": ["train", "dev", "test"]
        },

2. Create a new `.jl` file in `src/corpora`

3. Add the following line at the beginning of the file:  

        const <idname> = get_nametype(<dataset name>)

    - Replace `<idname>` with an identifier of your dataset (for example, `timit_id`).
    - Replace `<dataset name>` with a string containing the name of the dataset (same as referenced in `corpora.json`).

4. If your dataset is downloadable, you can implement

        Base.download(::DatasetBuilder{<idname>}, dir::AbstractString)

5. It is mandatory to implement the `prepare()` function as such: 

        prepare(::DatasetBuilder{<idname>}, inputdir, outputdir; <keyword arguments>)

    You can add any keyword argument.  
    This function must create the following files in outputdir:
      - `recordings.jsonl`
      - `annotations.jsonl` or `annotations-<subset>.jsonl` for each subset

That's it, you can now use 
```julia
dataset("name", inputdir, outputdir; <keyword arguments>)
```

## DatasetBuilder and utilities

```@docs
DatasetBuilder
DatasetBuilder(name::Symbol)
SpeechDatasets.declareBuilder(name::Symbol)
get_kwargs(func_name::Function, args_types::Tuple)
get_nametype(name::String)
Base.download
prepare
```